@@ -832,14 +832,14 @@ void GLWorld_CreateShaders (void)
 		"attribute vec2 TexCoords;\n"
 		"attribute vec2 LMCoords;\n"
 		"\n"
+		"varying float FogFragCoord;\n"
+		"\n"
 		"void main()\n"
 		"{\n"
 		"	gl_TexCoord[0] = vec4(TexCoords, 0.0, 0.0);\n"
 		"	gl_TexCoord[1] = vec4(LMCoords, 0.0, 0.0);\n"
 		"	gl_Position = gl_ModelViewProjectionMatrix * vec4(Vert, 1.0);\n"
-		"	// fog\n"
-		"	vec3 ecPosition = vec3(gl_ModelViewMatrix * vec4(Vert, 1.0));\n"
-		"	gl_FogFragCoord = abs(ecPosition.z);\n"
+		"	FogFragCoord = gl_Position.w;\n"
 		"}\n";
 	
 	const GLchar *fragSource = \
@@ -852,6 +852,9 @@ void GLWorld_CreateShaders (void)
 		"uniform bool UseOverbright;\n"
 		"uniform bool UseAlphaTest;\n"
 		"uniform float Alpha;\n"
+		"\n"
+		"varying float FogFragCoord;\n"
+		"\n"
 		"void main()\n"
 		"{\n"
 		"	vec4 result = texture2D(Tex, gl_TexCoord[0].xy);\n"
@@ -863,11 +866,10 @@ void GLWorld_CreateShaders (void)
 		"	if (UseFullbrightTex)\n"
 		"		result += texture2D(FullbrightTex, gl_TexCoord[0].xy);\n"
 		"	result = clamp(result, 0.0, 1.0);\n"
-		"	// apply GL_EXP2 fog (from the orange book)\n"
-		"	float fog = exp(-gl_Fog.density * gl_Fog.density * gl_FogFragCoord * gl_FogFragCoord);\n"
+		"	float fog = exp(-gl_Fog.density * gl_Fog.density * FogFragCoord * FogFragCoord);\n"
 		"	fog = clamp(fog, 0.0, 1.0);\n"
 		"	result = mix(gl_Fog.color, result, fog);\n"
-		"	result.a = Alpha;\n"
+		"	result.a = Alpha;\n" // FIXME: This will make almost transparent things cut holes though heavy fog
 		"	gl_FragColor = result;\n"
 		"}\n";
 	
